@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2011 by The BRLTTY Developers.
+ * Copyright (C) 1995-2012 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -192,11 +192,8 @@ openUsbPort (const char *device) {
 static int
 configureUsbPort (unsigned int baud) {
   const SerialParameters parameters = {
-    .baud = baud,
-    .flowControl = SERIAL_FLOW_NONE,
-    .dataBits = 8,
-    .stopBits = 1,
-    .parity = SERIAL_PARITY_NONE
+    SERIAL_DEFAULT_PARAMETERS,
+    .baud = baud
   };
 
   return usbSetSerialParameters(usbChannel->device, &parameters);
@@ -442,10 +439,11 @@ brl_construct (BrailleDisplay *brl, char **parameters, const char *device) {
     const unsigned int *baud = baudTable;
 
     while (io->configurePort(*baud)) {
-      time_t start = time(NULL);
+      TimeValue start;
       int count = 0;
       unsigned char byte;
 
+      getCurrentTime(&start);
       charactersPerSecond = *baud / 10;
       controlKey = NO_CONTROL_KEY;
 
@@ -475,7 +473,7 @@ brl_construct (BrailleDisplay *brl, char **parameters, const char *device) {
         }
 
         if (++count == 100) break;
-        if (difftime(time(NULL), start) > 5.0) break;
+        if (millisecondsSince(&start) > 5) break;
       }
 
       if (!*++baud) baud = baudTable;
