@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2011 by The BRLTTY Developers.
+ * Copyright (C) 1995-2012 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -537,7 +537,7 @@ static int
 brl_writeWindow (BrailleDisplay *brl, const wchar_t *text) {
   size_t count = brl->textColumns * brl->textRows;
 
-  if (cellsHaveChanged(previousCells, brl->buffer, count, NULL, NULL)) {
+  if (cellsHaveChanged(previousCells, brl->buffer, count, NULL, NULL, NULL)) {
     if (!writeCells(brl)) return 0;
   }
 
