@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2011 by The BRLTTY Developers.
+ * Copyright (C) 1995-2012 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -179,7 +179,7 @@ static int		NbCols = 0;			/* number of cells available */
 static char		IdentString[41] = "Device not recognized!";
 static int		gio_fd = -1;
 
-static short	ReWrite = 0;		/* 1 if display need to be rewritten */
+static int	ReWrite = 0;		/* 1 if display need to be rewritten */
 static short	ReWrite_LCD = 0;		/* same as rewrite, for LCD */
 static int	OffsetType = BRL_BLK_ROUTE;
 static int	context = 0;
@@ -193,13 +193,13 @@ static int readbrlkey(BrailleDisplay *brl, char key_context);
 
 static int begblk(BrailleDisplay *brl)
 {
-  OffsetType = BRL_BLK_CUTBEGIN;
+  OffsetType = BRL_BLK_CLIP_NEW;
   return (EOF);
 }
 
 static int endblk(BrailleDisplay *brl)
 {
-  OffsetType = BRL_BLK_CUTLINE;
+  OffsetType = BRL_BLK_COPY_LINE;
   return (EOF);
 }
 
@@ -409,13 +409,7 @@ static int brl_writeWindow (BrailleDisplay *brl, const wchar_t *text)
      {
        return 1;
      }
-   if (!ReWrite)
-     /* We update the display only if it has changed */
-     if (cellsHaveChanged(prevdata, brl->buffer, NbCols, NULL, NULL))
-       {
-	 ReWrite = 1;
-       }
-   if (ReWrite)
+   if (cellsHaveChanged(prevdata, brl->buffer, NbCols, NULL, NULL, &ReWrite))
      {
       /* right end cells don't have to be transmitted if all dots down */
        char OutBuf[i + 1];
@@ -428,7 +422,6 @@ static int brl_writeWindow (BrailleDisplay *brl, const wchar_t *text)
        for (j = NbCols - 1; j >= 0; j--)
 	 *p++ = translateOutputCell(brl->buffer[j]);
        WriteToBrlDisplay (brl, p - OutBuf, OutBuf);
-       ReWrite = 0;
      }
    return 1;
 }
@@ -441,7 +434,7 @@ static int Program(BrailleDisplay *brl)
 
   if (p)
     {
-      message(NULL, "Level 1 ...", MSG_NODELAY);
+      message(NULL, gettext("level 1 ..."), MSG_NODELAY);
       while ((key = readbrlkey(brl, CTX_COMMANDS)) != VK_FGB)
 	{
 	  for (i = 0; p[i].brl_key; i++)
@@ -465,7 +458,7 @@ static int Program(BrailleDisplay *brl)
 
 static int SynthControl(BrailleDisplay *brl)
 {
-  message(NULL, "Level 4 ...", MSG_NODELAY);
+  message(NULL, gettext("level 4 ..."), MSG_NODELAY);
   context = IN_LEVEL4;
   return (EOF);
 }
@@ -547,9 +540,9 @@ static int handle_routekey(BrailleDisplay *brl, int routekey)
 	   case 0x06: /* Console Switching */
  	     context = 0;
 	     if (NbCols == 20)
-	       message(NULL, "switch:1 2 3 4 5 6 t", MSG_NODELAY);
+	       message(NULL, gettext("switch:1 2 3 4 5 6 t"), MSG_NODELAY);
 	     else
-	       message(NULL, "switch:1 2 3 4 5 6 7 t", MSG_NODELAY);
+	       message(NULL, gettext("switch:1 2 3 4 5 6 7 t"), MSG_NODELAY);
 	     context = 2;
 	     ReWrite = 0;
 	     res = BRL_CMD_NOOP;
@@ -625,7 +618,7 @@ static int handle_routekey(BrailleDisplay *brl, int routekey)
 	  }
 	if (flag == 1)
 	  {
-	    message(NULL, "i:tty hlp info t", MSG_NODELAY);
+	    message(NULL, gettext("i:tty hlp info t"), MSG_NODELAY);
 	    context = 1;
 	    res = BRL_CMD_NOOP;
 	  }
@@ -696,7 +689,7 @@ static int	key_handle(BrailleDisplay *brl, unsigned char *buf, char key_context)
     }
   if (keys == 0x280 && !alt && !control) /* alt */
     {
-      message(NULL, "! alt", MSG_NODELAY);
+      message(NULL, gettext("! alt"), MSG_NODELAY);
       context = 4;
       ReWrite = 0;
       alt = 1;
@@ -705,7 +698,7 @@ static int	key_handle(BrailleDisplay *brl, unsigned char *buf, char key_context)
   if (alt && control)
     {
       context = 0;
-      message(NULL, "! alt control", MSG_NODELAY);
+      message(NULL, gettext("! alt control"), MSG_NODELAY);
       context = 4;
     }
   if (keys == 0x2c0 && control)
@@ -718,7 +711,7 @@ static int	key_handle(BrailleDisplay *brl, unsigned char *buf, char key_context)
   if (keys == 0x2c0 && !control) /* control */
     {
       control = 1;
-      message(NULL, "! control ", MSG_NODELAY);
+      message(NULL, gettext("! control"), MSG_NODELAY);
       context = 4;
       ReWrite = 0;
       res = BRL_CMD_NOOP;
