@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2011 by The BRLTTY Developers.
+ * Copyright (C) 1995-2012 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -116,7 +116,7 @@ static int fullFreshenEvery;
    if the display was turned off. */
 /* We record the time at which the last ping reply was received,
    and the time at which the last ping (query) was sent. */
-static struct timeval last_ping, last_ping_sent;
+static TimeValue last_ping, last_ping_sent;
 /* that many pings are sent, that many chances to reply */
 #define PING_MAXNQUERY 2
 static int pings; /* counts number of pings sent since last reply */
@@ -131,7 +131,7 @@ static int must_init_oldstat = 1;
 #define NONREPEAT_TIMEOUT 300
 #define READBRL_SKIP_TIME 300
 static int lastcmd = EOF;
-static struct timeval lastcmd_time, last_readbrl_time;
+static TimeValue lastcmd_time, last_readbrl_time;
 /* Those functions it is OK to repeat */
 static int repeat_list[] =
 {BRL_CMD_FWINRT, BRL_CMD_FWINLT, BRL_CMD_LNUP, BRL_CMD_LNDN, BRL_CMD_WINUP, BRL_CMD_WINDN,
@@ -465,7 +465,7 @@ brl_construct (BrailleDisplay *brl, char **parameters, const char *device)
 #ifdef HIGHBAUD
   if(speed == 2){ /* if supported (PB) go to 19.2Kbps */
     serialWriteData (serialDevice, BRL_UART192, DIM_BRL_UART192);
-    serialDrainOutput(serialDevice);
+    serialAwaitOutput(serialDevice);
     approximateDelay(BAUD_DELAY);
     if(!serialSetBaud(serialDevice, serialBaud=19200)) goto failure;
     logMessage(LOG_DEBUG,"Switched to 19200bps. Checking if display followed.");
@@ -475,7 +475,7 @@ brl_construct (BrailleDisplay *brl, char **parameters, const char *device)
       logMessage(LOG_INFO,"Display did not respond at 19200bps, "
 	         "falling back to 9600bps.");
       if(!serialSetBaud(serialDevice, serialBaud=9600)) goto failure;
-      serialDrainOutput(serialDevice);
+      serialAwaitOutput(serialDevice);
       approximateDelay(BAUD_DELAY); /* just to be safe */
       if(QueryDisplay(reply)) {
 	logMessage(LOG_INFO,"Found display again at 9600bps.");
@@ -492,9 +492,9 @@ brl_construct (BrailleDisplay *brl, char **parameters, const char *device)
   charactersPerSecond = serialBaud / serialGetCharacterBits(serialDevice);
 
   /* Mark time of last command to initialize typematic watch */
-  gettimeofday (&last_ping, NULL);
-  memcpy(&last_readbrl_time, &last_ping, sizeof(struct timeval));
-  memcpy(&lastcmd_time, &last_ping, sizeof(struct timeval));
+  getCurrentTime(&last_ping);
+  last_readbrl_time = last_ping;
+  lastcmd_time = last_ping;
   lastcmd = EOF;
   pings=0;
   must_init_oldstat = 1;
@@ -638,7 +638,7 @@ brl_writeWindow (BrailleDisplay *brl, const wchar_t *text)
   }else if(no_multiple_updates){
     unsigned int from, to;
     
-    if (cellsHaveChanged(prevdata, dispbuf, ncells, &from, &to)) {
+    if (cellsHaveChanged(prevdata, dispbuf, ncells, &from, &to, NULL)) {
       display (brl, dispbuf, from, to);
     }
   }else{
@@ -766,15 +766,15 @@ cut_cursor (BrailleDisplay *brl)
       prevdata[pos] = oldchar;
 
       while ((key = brl_readCommand (brl, KTB_CTX_DEFAULT)) == EOF) approximateDelay(1); /* just yield */
-      if((key &BRL_MSK_BLK) == BRL_BLK_CUTBEGIN)
-	  res = BRL_BLK_CUTBEGIN + pos;
-      else if((key &BRL_MSK_BLK) == BRL_BLK_CUTAPPEND)
-	  res = BRL_BLK_CUTAPPEND + pos;
-      else if((key &BRL_MSK_BLK) == BRL_BLK_CUTRECT) {
-	  res = BRL_BLK_CUTRECT + pos;
+      if((key &BRL_MSK_BLK) == BRL_BLK_CLIP_NEW)
+	  res = BRL_BLK_CLIP_NEW + pos;
+      else if((key &BRL_MSK_BLK) == BRL_BLK_CLIP_ADD)
+	  res = BRL_BLK_CLIP_ADD + pos;
+      else if((key &BRL_MSK_BLK) == BRL_BLK_COPY_RECT) {
+	  res = BRL_BLK_COPY_RECT + pos;
 	  pos = -1;
-      }else if((key &BRL_MSK_BLK) == BRL_BLK_CUTLINE) {
-	  res = BRL_BLK_CUTLINE + pos;
+      }else if((key &BRL_MSK_BLK) == BRL_BLK_COPY_LINE) {
+	  res = BRL_BLK_COPY_LINE + pos;
 	  pos = -1;
       }else switch (key)
 	{
@@ -871,10 +871,10 @@ brl_readCommand (BrailleDisplay *brl, KeyTableCommandContext context)
   char buf[MAXREAD], /* read buffer */
        packtype = 0; /* type of packet being received (state) */
   unsigned i;
-  struct timeval now;
+  TimeValue now;
   int skip_this_cmd = 0;
 
-  gettimeofday (&now, NULL);
+  getCurrentTime(&now);
   if (millisecondsBetween(&last_readbrl_time, &now) > READBRL_SKIP_TIME)
     /* if the key we get this time is the same as the one we returned at last
        call, and if it has been abnormally long since we were called
@@ -882,7 +882,7 @@ brl_readCommand (BrailleDisplay *brl, KeyTableCommandContext context)
        the bytes we will read can be old... so we forget this key, if it is
        a repeat. */
     skip_this_cmd = 1;
-  memcpy(&last_readbrl_time, &now, sizeof(struct timeval));
+  last_readbrl_time = now;
        
   if(pending_cmd != EOF){
     res = pending_cmd;
@@ -914,23 +914,23 @@ brl_readCommand (BrailleDisplay *brl, KeyTableCommandContext context)
 	return BRL_CMD_RESTARTBRL;
       else if(ping_due){
 	logMessage(LOG_DEBUG,"Display idle: sending query");
-	serialDrainOutput(serialDevice);
+	serialAwaitOutput(serialDevice);
 	approximateDelay(2*SEND_DELAY);
 	serialWriteData (serialDevice, BRL_QUERY, DIM_BRL_QUERY);
 	if(slow_update == 1)
-	  serialDrainOutput(serialDevice);
+	  serialAwaitOutput(serialDevice);
 	else if(slow_update == 2){
-	  serialDrainOutput(serialDevice);
+	  serialAwaitOutput(serialDevice);
 	  approximateDelay(SEND_DELAY);
 	}
 	pings++;
-	gettimeofday(&last_ping_sent, NULL);
+	getCurrentTime(&last_ping_sent);
       }
     }
     return (EOF);
   }
   /* there was some input, we heard something. */
-  gettimeofday(&last_ping, NULL);
+  getCurrentTime(&last_ping);
   pings=0;
 
 #ifdef RECV_DELAY
@@ -979,9 +979,7 @@ brl_readCommand (BrailleDisplay *brl, KeyTableCommandContext context)
   }
 
   if(packtype == K_BATTERY){
-    const char *text = "-><- Display battery is low";
-    if(brl_cols < strlen(text)) text = "Display battery low";
-    message(NULL, text, MSG_WAITKEY);
+    message(NULL, gettext("battery low"), MSG_WAITKEY);
     return (EOF);
   }else if(packtype == K_QUERYREP){
     /* flush the last 10bytes of the reply. */
@@ -1056,8 +1054,8 @@ brl_readCommand (BrailleDisplay *brl, KeyTableCommandContext context)
     ignore_routing = 1;
     if(sw_howmany == 1){
       switch(code){
-	KEYAND(KEY_BUT3) KEY(KEY_BRIGHT, BRL_BLK_CUTBEGIN + sw_which[0]);
-	KEYAND(KEY_BUT2) KEY(KEY_BLEFT, BRL_BLK_CUTRECT + sw_which[0]);
+	KEYAND(KEY_BUT3) KEY(KEY_BRIGHT, BRL_BLK_CLIP_NEW + sw_which[0]);
+	KEYAND(KEY_BUT2) KEY(KEY_BLEFT, BRL_BLK_COPY_RECT + sw_which[0]);
 	KEYAND(KEY_R2DN) KEY (KEY_BDOWN, BRL_BLK_NXINDENT + sw_which[0]);
 	KEYAND(KEY_R2UP) KEY (KEY_BUP, BRL_BLK_PRINDENT + sw_which[0]);
 	KEY (KEY_CROUND, BRL_BLK_SETMARK + sw_which[0]);
@@ -1070,10 +1068,10 @@ brl_readCommand (BrailleDisplay *brl, KeyTableCommandContext context)
     }else if(sw_howmany == 2) {
       if(sw_which[0]+1 == sw_which[1]
 	 && (code == KEY_BRIGHT || code == KEY_BUT3))
-	res = BRL_BLK_CUTAPPEND + sw_which[0];
+	res = BRL_BLK_CLIP_ADD + sw_which[0];
       else if(sw_which[0]+1 == sw_which[1]
 	 && (code == KEY_BLEFT || code == KEY_BUT2))
-	res = BRL_BLK_CUTLINE + sw_which[1];
+	res = BRL_BLK_COPY_LINE + sw_which[1];
       else if(sw_which[0]==0 && sw_which[1]==1){
 	switch(code){
 	  KEYAND(KEY_R2DN) KEY (KEY_BDOWN, BRL_CMD_NXPGRPH);
@@ -1098,9 +1096,9 @@ brl_readCommand (BrailleDisplay *brl, KeyTableCommandContext context)
 #if 0
      else if (sw_howmany == 3 && sw_which[1] == sw_lastkey - 1
 	       && sw_which[2] == sw_lastkey)
-	res = BRL_BLK_CUTBEGIN + sw_which[0];
+	res = BRL_BLK_CLIP_NEW + sw_which[0];
       else if (sw_howmany == 3 && sw_which[0] == 0 && sw_which[1] == 1)
- 	res = BRL_BLK_CUTRECT + sw_which[2];
+ 	res = BRL_BLK_COPY_RECT + sw_which[2];
 #endif /* 0 */
       else if(sw_howmany == 2 && sw_which[0] == 1 && sw_which[1] == 2)
  	res = BRL_CMD_PASTE;
@@ -1130,8 +1128,8 @@ brl_readCommand (BrailleDisplay *brl, KeyTableCommandContext context)
 	}
 #endif /* 0 */
       else if(sw_howmany == 3 && sw_which[0]+2 == sw_which[1]){
-	  res = BRL_BLK_CUTBEGIN + sw_which[0];
-	  pending_cmd = BRL_BLK_CUTRECT + sw_which[2];
+	  res = BRL_BLK_CLIP_NEW + sw_which[0];
+	  pending_cmd = BRL_BLK_COPY_RECT + sw_which[2];
 	}
     }
   else switch (code){
@@ -1196,10 +1194,10 @@ brl_readCommand (BrailleDisplay *brl, KeyTableCommandContext context)
     KEY (KEY_CDOWN | KEY_BDOWN | KEY_BRIGHT, BRL_BLK_ROUTE + 3 * brl_cols / 4 - 1);
 
   /* Emulation of routing keys for cut&paste */
-    KEY (KEY_CLEFT | KEY_BROUND, BRL_BLK_CUTBEGIN +0);
-    KEY (KEY_CLEFT | KEY_BROUND | KEY_BUP, BRL_BLK_CUTAPPEND +0);
-    KEY (KEY_CRIGHT | KEY_BROUND, BRL_BLK_CUTRECT +brl_cols-1);
-    KEY (KEY_CRIGHT | KEY_BROUND | KEY_BUP, BRL_BLK_CUTLINE +brl_cols-1);
+    KEY (KEY_CLEFT | KEY_BROUND, BRL_BLK_CLIP_NEW +0);
+    KEY (KEY_CLEFT | KEY_BROUND | KEY_BUP, BRL_BLK_CLIP_ADD +0);
+    KEY (KEY_CRIGHT | KEY_BROUND, BRL_BLK_COPY_RECT +brl_cols-1);
+    KEY (KEY_CRIGHT | KEY_BROUND | KEY_BUP, BRL_BLK_COPY_LINE +brl_cols-1);
     KEY (KEY_CLEFT | KEY_CRIGHT | KEY_BROUND, CMD_CUT_CURSOR);  /* special: see
 	 				    at the end of this fn */
   /* paste */
@@ -1260,11 +1258,11 @@ brl_readCommand (BrailleDisplay *brl, KeyTableCommandContext context)
   /* If this is a typematic repetition of some key other than movement keys */
   if (lastcmd == res && !is_repeat_cmd (res)){
     if(skip_this_cmd){
-      gettimeofday (&lastcmd_time, NULL);
+      getCurrentTime(&lastcmd_time);
       res = EOF;
     }else{
       /* if to short a time has elapsed since last command, ignore this one */
-      gettimeofday (&now, NULL);
+      getCurrentTime(&now);
       if (millisecondsBetween(&lastcmd_time, &now) < NONREPEAT_TIMEOUT)
 	res = EOF;
     }
@@ -1272,7 +1270,7 @@ brl_readCommand (BrailleDisplay *brl, KeyTableCommandContext context)
   /* reset timer to avoid unwanted typematic */
   if (res != EOF){
     lastcmd = res;
-    gettimeofday (&lastcmd_time, NULL);
+    getCurrentTime(&lastcmd_time);
   }
 
   /* Special: */
