@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2011 by The BRLTTY Developers.
+ * Copyright (C) 1995-2012 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -33,7 +33,6 @@
 #include "log.h"
 #include "device.h"
 #include "parse.h"
-#include "misc.h"
 #include "system.h"
 #include "sys_linux.h"
 #include "charset.h"
@@ -303,21 +302,28 @@ convertCharacter (const wchar_t *character) {
 }
 
 static int
-setDeviceName (const char **name, const char *const *names, const char *description, int mode) {
-  return (*name = resolveDeviceName(names, description, mode)) != NULL;
+setDeviceName (const char **name, const char *const *names, const char *description) {
+  return (*name = resolveDeviceName(names, description)) != NULL;
 }
 
 static char *
 vtName (const char *name, unsigned char vt) {
+  char *string;
+
   if (vt) {
     size_t length = strlen(name);
     char buffer[length+4];
+
     if (name[length-1] == '0') length -= 1;
     strncpy(buffer, name, length);
     sprintf(buffer+length,  "%u", vt);
-    return strdupWrapper(buffer);
+    string = strdup(buffer);
+  } else {
+    string = strdup(name);
   }
-  return strdupWrapper(name);
+
+  if (!string) logMallocError();
+  return string;
 }
 
 static const char *consoleName = NULL;
@@ -326,7 +332,7 @@ static int consoleDescriptor;
 static int
 setConsoleName (void) {
   static const char *const names[] = {"tty0", "vc/0", NULL};
-  return setDeviceName(&consoleName, names, "console", R_OK|W_OK);
+  return setDeviceName(&consoleName, names, "console");
 }
 
 static void
@@ -364,7 +370,7 @@ static unsigned char virtualTerminal;
 static int
 setScreenName (void) {
   static const char *const names[] = {"vcsa", "vcsa0", "vcc/a", NULL};
-  return setDeviceName(&screenName, names, "screen", R_OK|W_OK);
+  return setDeviceName(&screenName, names, "screen");
 }
 
 static void
