@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2011 by The BRLTTY Developers.
+ * Copyright (C) 1995-2012 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -60,26 +60,26 @@ spk_isSpeaking (SpeechSynthesizer *spk) {
 }
 #endif /* SPK_HAVE_TRACK */
 
-#ifdef SPK_HAVE_RATE
-static void
-spk_rate (SpeechSynthesizer *spk, unsigned char setting) {
-}
-#endif /* SPK_HAVE_RATE */
-
 #ifdef SPK_HAVE_VOLUME
 static void
-spk_volume (SpeechSynthesizer *spk, unsigned char setting) {
+spk_setVolume (SpeechSynthesizer *spk, unsigned char setting) {
 }
 #endif /* SPK_HAVE_VOLUME */
 
+#ifdef SPK_HAVE_RATE
+static void
+spk_setRate (SpeechSynthesizer *spk, unsigned char setting) {
+}
+#endif /* SPK_HAVE_RATE */
+
 #ifdef SPK_HAVE_PITCH
 static void
-spk_pitch (SpeechSynthesizer *spk, unsigned char setting) {
+spk_setPitch (SpeechSynthesizer *spk, unsigned char setting) {
 }
 #endif /* SPK_HAVE_PITCH */
 
 #ifdef SPK_HAVE_PUNCTUATION
 static void
-spk_punctuation (SpeechSynthesizer *spk, SpeechPunctuation setting) {
+spk_setPunctuation (SpeechSynthesizer *spk, SpeechPunctuation setting) {
 }
 #endif /* SPK_HAVE_PUNCTUATION */
