@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2011 by The BRLTTY Developers.
+ * Copyright (C) 1995-2012 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -18,6 +18,8 @@
 
 #include "prologue.h"
 
+#include "log.h"
+#include "file.h"
 #include "atb.h"
 #include "atb_internal.h"
 
@@ -36,3 +38,28 @@ unsigned char
 convertAttributesToDots (AttributesTable *table, unsigned char attributes) {
   return table->header.fields->attributesToDots[attributes];
 }
+
+int
+replaceAttributesTable (const char *directory, const char *name) {
+  int ok = 0;
+  char *path;
+
+  if ((path = makeAttributesTablePath(directory, name))) {
+    AttributesTable *newTable;
+
+    logMessage(LOG_DEBUG, "compiling attributes table: %s", path);
+    if ((newTable = compileAttributesTable(path))) {
+      AttributesTable *oldTable = attributesTable;
+      attributesTable = newTable;
+      destroyAttributesTable(oldTable);
+      ok = 1;
+    } else {
+      logMessage(LOG_ERR, "%s: %s", gettext("cannot compile attributes table"), path);
+    }
+
+    free(path);
+  }
+
+  if (!ok) logMessage(LOG_ERR, "%s: %s", gettext("cannot load attributes table"), name);
+  return ok;
+}
