@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2011 by The BRLTTY Developers.
+ * Copyright (C) 1995-2012 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -20,13 +20,16 @@
 
 #include <stdio.h>
 #include <string.h>
+#include <errno.h>
  
+#include "log.h"
 #include "file.h"
 #include "ctb.h"
 #include "ctb_internal.h"
 #include "datafile.h"
 #include "dataarea.h"
 #include "brldots.h"
+#include "hostcmd.h"
 
 typedef struct {
   unsigned char length;
@@ -637,10 +640,86 @@ processContractionTableLine (DataFile *file, void *data) {
   }
 }
 
+int
+startContractionCommand (ContractionTable *table) {
+  if (!table->data.external.commandStarted) {
+    const char *command[] = {table->command, NULL};
+    HostCommandOptions options;
+
+    initializeHostCommandOptions(&options);
+    options.asynchronous = 1;
+    options.standardInput = &table->data.external.standardInput;
+    options.standardOutput = &table->data.external.standardOutput;
+
+    logMessage(LOG_DEBUG, "starting external contraction table: %s", table->command);
+    if (runHostCommand(command, &options) != 0) return 0;
+    logMessage(LOG_DEBUG, "external contraction table started: %s", table->command);
+
+    table->data.external.commandStarted = 1;
+  }
+
+  return 1;
+}
+
+void
+stopContractionCommand (ContractionTable *table) {
+  if (table->data.external.commandStarted) {
+    fclose(table->data.external.standardInput);
+    fclose(table->data.external.standardOutput);
+
+    logMessage(LOG_DEBUG, "external contraction table stopped: %s", table->command);
+    table->data.external.commandStarted = 0;
+  }
+}
+
+static void
+initializeCommonFields (ContractionTable *table) {
+  table->characters.array = NULL;
+  table->characters.size = 0;
+  table->characters.count = 0;
+
+  table->cache.input.characters = NULL;
+  table->cache.input.size = 0;
+  table->cache.input.count = 0;
+
+  table->cache.output.cells = NULL;
+  table->cache.output.size = 0;
+  table->cache.output.count = 0;
+
+  table->cache.offsets.array = NULL;
+  table->cache.offsets.size = 0;
+  table->cache.offsets.count = 0;
+}
+
 ContractionTable *
 compileContractionTable (const char *fileName) {
   ContractionTable *table = NULL;
 
+  if (isHostCommand(fileName)) {
+    if ((table = malloc(sizeof(*table)))) {
+      memset(table, 0, sizeof(*table));
+
+      if ((table->command = strdup(fileName))) {
+        initializeCommonFields(table);
+        table->data.external.commandStarted = 0;
+
+        if (startContractionCommand(table)) {
+          return table;
+        }
+
+        free(table->command);
+      } else {
+        logMallocError();
+      }
+
+      free(table);
+    } else {
+      logMallocError();
+    }
+
+    return NULL;
+  }
+
   if (setGlobalTableVariables(CONTRACTION_TABLE_EXTENSION, CONTRACTION_SUBTABLE_EXTENSION)) {
     ContractionTableData ctd;
     memset(&ctd, 0, sizeof(ctd));
@@ -665,13 +744,14 @@ compileContractionTable (const char *fileName) {
           if (processDataFile(fileName, processContractionTableLine, &ctd)) {
             if (saveCharacterTable(&ctd)) {
               if ((table = malloc(sizeof(*table)))) {
-                table->header.fields = getContractionTableHeader(&ctd);
-                table->size = getDataSize(ctd.area);
-                resetDataArea(ctd.area);
+                initializeCommonFields(table);
+                table->command = NULL;
 
-                table->characters = NULL;
-                table->charactersSize = 0;
-                table->characterCount = 0;
+                table->data.internal.header.fields = getContractionTableHeader(&ctd);
+                table->data.internal.size = getDataSize(ctd.area);
+                resetDataArea(ctd.area);
+              } else {
+                logMallocError();
               }
             }
           }
@@ -691,18 +771,44 @@ compileContractionTable (const char *fileName) {
 
 void
 destroyContractionTable (ContractionTable *table) {
-  if (table->characters) {
-    free(table->characters);
-    table->characters = NULL;
+  if (table->characters.array) {
+    free(table->characters.array);
+    table->characters.array = NULL;
   }
 
-  if (table->size) {
-    free(table->header.fields);
+  if (table->cache.input.characters) {
+    free(table->cache.input.characters);
+    table->cache.input.characters = NULL;
+  }
+
+  if (table->cache.output.cells) {
+    free(table->cache.output.cells);
+    table->cache.output.cells = NULL;
+  }
+
+  if (table->cache.offsets.array) {
+    free(table->cache.offsets.array);
+    table->cache.offsets.array = NULL;
+  }
+
+  if (table->command) {
+    stopContractionCommand(table);
+    free(table->command);
     free(table);
+  } else {
+    if (table->data.internal.size) {
+      free(table->data.internal.header.fields);
+      free(table);
+    }
   }
 }
 
 char *
 ensureContractionTableExtension (const char *path) {
-  return ensureExtension(path, CONTRACTION_TABLE_EXTENSION);
+  return ensureFileExtension(path, CONTRACTION_TABLE_EXTENSION);
+}
+
+char *
+makeContractionTablePath (const char *directory, const char *name) {
+  return makeFilePath(directory, name, CONTRACTION_TABLE_EXTENSION);
 }
