@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2011 by The BRLTTY Developers.
+ * Copyright (C) 1995-2012 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -21,9 +21,6 @@
 #include "log.h"
 #include "driver.h"
 
-static int logInputPackets = 0;
-static int logOutputPackets = 0;
-
 void
 unsupportedDevice (const char *identifier) {
   logMessage(LOG_WARNING, "unsupported device: %s", identifier);
@@ -31,17 +28,17 @@ unsupportedDevice (const char *identifier) {
 
 static void
 logPacket (const char *description, const void *packet, size_t size) {
-  logBytes(LOG_WARNING, description, packet, size);
+  logBytes(categoryLogLevel, description, packet, size);
 }
 
 void
 logOutputPacket (const void *packet, size_t size) {
-  if (logOutputPackets) logPacket("Output Packet", packet, size);
+  if (LOG_CATEGORY_FLAG(OUTPUT_PACKETS)) logPacket("Output Packet", packet, size);
 }
 
 void
 logInputPacket (const void *packet, size_t size) {
-  if (logInputPackets) logPacket("Input Packet", packet, size);
+  if (LOG_CATEGORY_FLAG(INPUT_PACKETS)) logPacket("Input Packet", packet, size);
 }
 
 void
