@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2011 by The BRLTTY Developers.
+ * Copyright (C) 1995-2012 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -19,15 +19,21 @@
 #include "prologue.h"
 
 #include <stdio.h>
+#include <stdarg.h>
 #include <string.h>
 #include <errno.h>
 #include <fcntl.h>
 #include <sys/stat.h>
 
+#undef CAN_GLOB
 #if defined(HAVE_GLOB_H)
+#define CAN_GLOB
 #include <glob.h>
+
 #elif defined(__MINGW32__)
+#define CAN_GLOB
 #include <io.h>
+
 #else /* glob: paradigm-specific global definitions */
 #warning file globbing support not available on this platform
 #endif /* glob: paradigm-specific global definitions */
@@ -35,6 +41,7 @@
 #include "log.h"
 #include "file.h"
 #include "menu.h"
+#include "prefs.h"
 #include "parse.h"
 
 typedef struct {
@@ -52,27 +59,48 @@ typedef struct {
   int offset;
 #endif /* glob: paradigm-specific field declarations */
 
-  const char **paths;
+  char **paths;
   int count;
   unsigned char setting;
-  const char *pathsArea[3];
+  char *pathsArea[3];
 } FileData;
 
+typedef struct {
+  Menu *menu;
+  unsigned opened:1;
+
+  unsigned int total;
+  unsigned int visible;
+} SubmenuData;
+
 struct MenuStruct {
-  MenuItem *items;
-  unsigned int size;
-  unsigned int count;
-  unsigned int index;
+  Menu *parent;
+
+  struct {
+    MenuItem *array;
+    unsigned int size;
+    unsigned int count;
+    unsigned int index;
+  } items;
 
   MenuItem *activeItem;
   char valueBuffer[0X10];
 };
 
+typedef struct {
+  int (*beginItem) (MenuItem *item);
+  void (*endItem) (MenuItem *item, int deallocating);
+  void (*activateItem) (MenuItem *item);
+  const char * (*getValue) (const MenuItem *item);
+  const char * (*getComment) (const MenuItem *item);
+} MenuItemMethods;
+
 struct MenuItemStruct {
   Menu *menu;
   unsigned char *setting;                 /* pointer to current value */
   MenuString name;                      /* item name for presentation */
 
+  const MenuItemMethods *methods;
   MenuItemTester *test;                     /* returns true if item should be presented */
   MenuItemChanged *changed;
 
@@ -80,99 +108,120 @@ struct MenuItemStruct {
   unsigned char maximum;                  /* highest valid value */
   unsigned char divisor;                  /* present only multiples of this value */
 
-  void (*beginItem) (MenuItem *item);
-  void (*endItem) (MenuItem *item, int deallocating);
-  const char * (*getValue) (const MenuItem *item);
-  const char * (*getComment) (const MenuItem *item);
-
   union {
     const MenuString *strings;
     FileData *files;
+    SubmenuData *submenu;
   } data;
 };
 
-char *
+static inline const char *
 getLocalText (const char *string) {
   return (string && *string)? gettext(string): "";
 }
 
+static const char *
+formatValue (Menu *menu, const char *format, ...) {
+  {
+    va_list arguments;
+
+    va_start(arguments, format);
+    vsnprintf(menu->valueBuffer, sizeof(menu->valueBuffer), format, arguments);
+    va_end(arguments);
+  }
+
+  return menu->valueBuffer;
+}
+
 Menu *
 newMenu (void) {
   Menu *menu = malloc(sizeof(*menu));
 
   if (menu) {
-    menu->items = NULL;
-    menu->size = 0;
-    menu->count = 0;
-    menu->index = 0;
+    menu->parent = NULL;
+    menu->items.array = NULL;
+    menu->items.size = 0;
+    menu->items.count = 0;
+    menu->items.index = 0;
     menu->activeItem = NULL;
   }
 
   return menu;
 }
 
-static void
+static int
 beginMenuItem (MenuItem *item) {
-  if (item->beginItem) {
-    item->beginItem(item);
-  }
+  return !item->methods->beginItem || item->methods->beginItem(item);
 }
 
 static void
 endMenuItem (MenuItem *item, int deallocating) {
-  if (item->endItem) {
-    item->endItem(item, deallocating);
-  }
+  if (item->methods->endItem) item->methods->endItem(item, deallocating);
 }
 
 void
 deallocateMenu (Menu *menu) {
   if (menu) {
-    if (menu->items) {
-      MenuItem *item = menu->items;
-      const MenuItem *end = item + menu->count;
+    if (menu->items.array) {
+      MenuItem *item = menu->items.array;
+      const MenuItem *end = item + menu->items.count;
 
       while (item < end) endMenuItem(item++, 1);
-      free(menu->items);
+      free(menu->items.array);
     }
 
     free(menu);
   }
 }
 
-MenuItem *
-getMenuItem (Menu *menu, unsigned int index) {
-  return (index < menu->count)? &menu->items[index]: NULL;
+Menu *
+getMenuParent (const Menu *menu) {
+  return menu->parent;
 }
 
 unsigned int
 getMenuSize (const Menu *menu) {
-  return menu->count;
+  return menu->items.count;
 }
 
 unsigned int
 getMenuIndex (const Menu *menu) {
-  return menu->index;
+  return menu->items.index;
 }
 
 MenuItem *
-getCurrentMenuItem (Menu *menu) {
-  MenuItem *newItem = getMenuItem(menu, menu->index);
-  MenuItem *oldItem = menu->activeItem;
+getMenuItem (Menu *menu, unsigned int index) {
+  return (index < menu->items.count)? &menu->items.array[index]: NULL;
+}
 
-  if (newItem != oldItem) {
-    if (oldItem) endMenuItem(oldItem, 0);
-    beginMenuItem(newItem);
-    menu->activeItem = newItem;
-  }
-
-  return newItem;
+static MenuItem *
+getSelectedMenuItem (Menu *menu) {
+  return getMenuItem(menu, menu->items.index);
 }
 
 static int
-testMenuItem (Menu *menu, unsigned int index) {
+testMenuItem (Menu *menu, unsigned int index, int all) {
   MenuItem *item = getMenuItem(menu, index);
-  return item && (!item->test || item->test());
+
+  if (!item) return 0;
+  if (all) return 1;
+  if (!item->test) return 1;
+  return item->test();
+}
+
+static inline int
+testMenuItemActive (Menu *menu, unsigned int index) {
+  return testMenuItem(menu, index, 0);
+}
+
+static inline int
+testMenuItemVisible (Menu *menu, unsigned int index) {
+  return testMenuItem(menu, index, prefs.showAllItems);
+}
+
+int
+isSettableMenuItem (const MenuItem *item) {
+  return !!item->setting;
 }
 
 const MenuString *
@@ -182,43 +231,31 @@ getMenuItemName (const MenuItem *item) {
 
 const char *
 getMenuItemValue (const MenuItem *item) {
-  return item->getValue(item);
+  return item->methods->getValue(item);
 }
 
 const char *
 getMenuItemComment (const MenuItem *item) {
-  return item->getComment(item);
+  return item->methods->getComment? item->methods->getComment(item): "";
 }
 
-static const char *
-getMenuItemValue_numeric (const MenuItem *item) {
-  Menu *menu = item->menu;
-  snprintf(menu->valueBuffer, sizeof(menu->valueBuffer), "%u", *item->setting);
-  return menu->valueBuffer;
-}
-
-static const char *
-getMenuItemComment_none (const MenuItem *item) {
-  return "";
-}
-
-MenuItem *
+static MenuItem *
 newMenuItem (Menu *menu, unsigned char *setting, const MenuString *name) {
-  if (menu->count == menu->size) {
-    unsigned int newSize = menu->size? (menu->size << 1): 0X10;
-    MenuItem *newItems = realloc(menu->items, (newSize * sizeof(*newItems)));
+  if (menu->items.count == menu->items.size) {
+    unsigned int newSize = menu->items.size? (menu->items.size << 1): 0X10;
+    MenuItem *newArray = realloc(menu->items.array, (newSize * sizeof(*newArray)));
 
-    if (!newItems) {
+    if (!newArray) {
       logMallocError();
       return NULL;
     }
 
-    menu->items = newItems;
-    menu->size = newSize;
+    menu->items.array = newArray;
+    menu->items.size = newSize;
   }
 
   {
-    MenuItem *item = getMenuItem(menu, menu->count++);
+    MenuItem *item = getMenuItem(menu, menu->items.count++);
 
     item->menu = menu;
     item->setting = setting;
@@ -226,6 +263,7 @@ newMenuItem (Menu *menu, unsigned char *setting, const MenuString *name) {
     item->name.label = getLocalText(name->label);
     item->name.comment = getLocalText(name->comment);
 
+    item->methods = NULL;
     item->test = NULL;
     item->changed = NULL;
 
@@ -233,11 +271,6 @@ newMenuItem (Menu *menu, unsigned char *setting, const MenuString *name) {
     item->maximum = 0;
     item->divisor = 1;
 
-    item->beginItem = NULL;
-    item->endItem = NULL;
-    item->getValue = getMenuItemValue_numeric;
-    item->getComment = getMenuItemComment_none;
-
     return item;
   }
 }
@@ -252,6 +285,15 @@ setMenuItemChanged (MenuItem *item, MenuItemChanged *handler) {
   item->changed = handler;
 }
 
+static const char *
+getValue_numeric (const MenuItem *item) {
+  return formatValue(item->menu, "%u", *item->setting);;
+}
+
+static const MenuItemMethods menuItemMethods_numeric = {
+  .getValue = getValue_numeric
+};
+
 MenuItem *
 newNumericMenuItem (
   Menu *menu, unsigned char *setting, const MenuString *name,
@@ -260,6 +302,7 @@ newNumericMenuItem (
   MenuItem *item = newMenuItem(menu, setting, name);
 
   if (item) {
+    item->methods = &menuItemMethods_numeric;
     item->minimum = minimum;
     item->maximum = maximum;
     item->divisor = divisor;
@@ -269,30 +312,33 @@ newNumericMenuItem (
 }
 
 static const char *
-getMenuItemValue_strings (const MenuItem *item) {
+getValue_strings (const MenuItem *item) {
   const MenuString *strings = item->data.strings;
   return getLocalText(strings[*item->setting - item->minimum].label);
 }
 
 static const char *
-getMenuItemComment_strings (const MenuItem *item) {
+getComment_strings (const MenuItem *item) {
   const MenuString *strings = item->data.strings;
   return getLocalText(strings[*item->setting - item->minimum].comment);
 }
 
-void
-setMenuItemStrings (MenuItem *item, const MenuString *strings, unsigned char count) {
-  item->getValue = getMenuItemValue_strings;
-  item->getComment = getMenuItemComment_strings;
-  item->data.strings = strings;
+static const MenuItemMethods menuItemMethods_strings = {
+  .getValue = getValue_strings,
+  .getComment = getComment_strings
+};
 
+static void
+setMenuItemStrings (MenuItem *item, const MenuString *strings, unsigned char count) {
+  item->methods = &menuItemMethods_strings;
+  item->data.strings = strings;
   item->minimum = 0;
   item->maximum = count - 1;
   item->divisor = 1;
 }
 
 MenuItem *
-newStringMenuItem (
+newStringsMenuItem (
   Menu *menu, unsigned char *setting, const MenuString *name,
   const MenuString *strings, unsigned char count
 ) {
@@ -322,8 +368,8 @@ qsortCompare_fileNames (const void *element1, const void *element2) {
   return strcmp(*name1, *name2);
 }
 
-static void
-beginMenuItem_files (MenuItem *item) {
+static int
+beginItem_files (MenuItem *item) {
   FileData *files = item->data.files;
   int index;
 
@@ -332,6 +378,7 @@ beginMenuItem_files (MenuItem *item) {
   files->paths[files->count] = NULL;
   index = files->count;
 
+#ifdef CAN_GLOB
   {
 #ifdef HAVE_FCHDIR
     int originalDirectory = open(".", O_RDONLY);
@@ -349,7 +396,8 @@ beginMenuItem_files (MenuItem *item) {
         files->glob.gl_offs = files->count;
 
         if (glob(files->pattern, GLOB_DOOFFS, NULL, &files->glob) == 0) {
-          files->paths = (const char **)files->glob.gl_pathv;
+          files->paths = files->glob.gl_pathv;
+
           /* The behaviour of gl_pathc is inconsistent. Some implementations
            * include the leading NULL pointers and some don't. Let's just
            * figure it out the hard way by finding the trailing NULL.
@@ -405,6 +453,7 @@ beginMenuItem_files (MenuItem *item) {
 #endif /* HAVE_FCHDIR */
     }
   }
+#endif /* CAN_GLOB */
 
   qsort(&files->paths[index], files->count-index, sizeof(*files->paths), qsortCompare_fileNames);
   if (files->none) files->paths[--index] = "";
@@ -429,10 +478,11 @@ beginMenuItem_files (MenuItem *item) {
   }
 
   item->maximum = files->count - 1;
+  return 1;
 }
 
 static void
-endMenuItem_files (MenuItem *item, int deallocating) {
+endItem_files (MenuItem *item, int deallocating) {
   FileData *files = item->data.files;
 
   if (files->current) free(files->current);
@@ -458,7 +508,7 @@ endMenuItem_files (MenuItem *item, int deallocating) {
 }
 
 static const char *
-getMenuItemValue_files (const MenuItem *item) {
+getValue_files (const MenuItem *item) {
   const FileData *files = item->data.files;
   const char *path;
 
@@ -472,8 +522,14 @@ getMenuItemValue_files (const MenuItem *item) {
   return path;
 }
 
+static const MenuItemMethods menuItemMethods_files = {
+  .beginItem = beginItem_files,
+  .endItem = endItem_files,
+  .getValue = getValue_files
+};
+
 MenuItem *
-newFileMenuItem (
+newFilesMenuItem (
   Menu *menu, const MenuString *name,
   const char *directory, const char *extension,
   const char *initial, int none
@@ -496,14 +552,12 @@ newFileMenuItem (
     if (pattern) {
       files->pattern = pattern; 
 
-      if ((files->initial = *initial? ensureExtension(initial, extension): strdup(""))) {
+      if ((files->initial = *initial? ensureFileExtension(initial, extension): strdup(""))) {
         if ((files->current = strdup(files->initial))) {
           MenuItem *item = newMenuItem(menu, &files->setting, name);
 
           if (item) {
-            item->beginItem = beginMenuItem_files;
-            item->endItem = endMenuItem_files;
-            item->getValue = getMenuItemValue_files;
+            item->methods = &menuItemMethods_files;
             item->data.files = files;
             return item;
           }
@@ -531,6 +585,173 @@ newFileMenuItem (
   return NULL;
 }
 
+static MenuItem *
+getParentMenuItem (const MenuItem *item) {
+  return getSelectedMenuItem(item->menu->parent);
+}
+
+static int
+beginItem_submenu (MenuItem *item) {
+  item->data.submenu->visible = 0;
+
+  {
+    Menu *menu = item->data.submenu->menu;
+    unsigned int size = getMenuSize(menu);
+    unsigned int index;
+
+    for (index=1; index<size; index+=1)
+      if (testMenuItemActive(menu, index))
+        item->data.submenu->visible += 1;
+
+    item->data.submenu->total = size - 1;
+  }
+
+  return 1;
+}
+
+static void
+endItem_submenu (MenuItem *item, int deallocating) {
+  if (deallocating) {
+    SubmenuData *submenu = item->data.submenu;
+
+    deallocateMenu(submenu->menu);
+    free(submenu);
+  }
+}
+
+static void
+activateItem_submenu (MenuItem *item) {
+  endMenuItem(item, 0);
+  item->data.submenu->opened = 1;
+}
+
+static const char *
+getValue_submenu (const MenuItem *item) {
+  return "--->";
+}
+
+static const char *
+getComment_submenu (const MenuItem *item) {
+  if (!prefs.showSubmenuSizes) return "";
+
+  {
+    const SubmenuData *submenu = item->data.submenu;
+
+    return prefs.showAllItems?
+             formatValue(item->menu, "%u", submenu->total):
+             formatValue(item->menu, "%u/%u", submenu->visible, submenu->total);
+  }
+}
+
+static const MenuItemMethods menuItemMethods_submenu = {
+  .beginItem = beginItem_submenu,
+  .endItem = endItem_submenu,
+  .activateItem = activateItem_submenu,
+  .getValue = getValue_submenu,
+  .getComment = getComment_submenu
+};
+
+static void
+activateItem_close (MenuItem *item) {
+  item = getParentMenuItem(item);
+  item->data.submenu->opened = 0;
+  beginMenuItem(item);
+}
+
+static const char *
+getValue_close (const MenuItem *item) {
+  return getLocalText(strtext("Close"));
+}
+
+static const char *
+getComment_close (const MenuItem *item) {
+  return getLocalText(getMenuItemName(getParentMenuItem(item))->label);
+}
+
+static const MenuItemMethods menuItemMethods_close = {
+  .activateItem = activateItem_close,
+  .getValue = getValue_close,
+  .getComment = getComment_close
+};
+
+Menu *
+newSubmenuMenuItem (
+  Menu *menu, const MenuString *name
+) {
+  SubmenuData *submenu;
+
+  if ((submenu = malloc(sizeof(*submenu)))) {
+    if ((submenu->menu = newMenu())) {
+      static const MenuString closeName = {.label="<---"};
+      MenuItem *close;
+
+      if ((close = newMenuItem(submenu->menu, NULL, &closeName))) {
+        MenuItem *item;
+
+        if ((item = newMenuItem(menu, NULL, name))) {
+          submenu->menu->parent = menu;
+          submenu->opened = 0;
+          close->methods = &menuItemMethods_close;
+
+          item->methods = &menuItemMethods_submenu;
+          item->data.submenu = submenu;
+          return submenu->menu;
+        }
+      }
+
+      deallocateMenu(submenu->menu);
+    }
+
+    free(submenu);
+  } else {
+    logMallocError();
+  }
+
+  return NULL;
+}
+
+int
+setMenuPreviousItem (Menu *menu) {
+  do {
+    if (!menu->items.index) menu->items.index = menu->items.count;
+    if (!menu->items.index) return 0;
+  } while (!testMenuItemVisible(menu, --menu->items.index));
+
+  return 1;
+}
+
+int
+setMenuNextItem (Menu *menu) {
+  if (menu->items.index >= menu->items.count) return 0;
+
+  do {
+    if (++menu->items.index == menu->items.count) menu->items.index = 0;
+  } while (!testMenuItemVisible(menu, menu->items.index));
+
+  return 1;
+}
+
+int
+setMenuFirstItem (Menu *menu) {
+  if (!menu->items.count) return 0;
+  menu->items.index = 0;
+  return testMenuItemVisible(menu, menu->items.index) || setMenuNextItem(menu);
+}
+
+int
+setMenuLastItem (Menu *menu) {
+  if (!menu->items.count) return 0;
+  menu->items.index = menu->items.count - 1;
+  return testMenuItemVisible(menu, menu->items.index) || setMenuPreviousItem(menu);
+}
+
+static int
+activateMenuItem (MenuItem *item) {
+  if (!item->methods->activateItem) return 0;
+  item->methods->activateItem(item);
+  return 1;
+}
+
 static int
 adjustMenuItem (const MenuItem *item, void (*adjust) (const MenuItem *item)) {
   int count = item->maximum - item->minimum + 1;
@@ -549,7 +770,9 @@ decrementMenuItem (const MenuItem *item) {
 }
 
 int
-changeMenuItemPrevious (const MenuItem *item) {
+changeMenuItemPrevious (MenuItem *item) {
+  if (activateMenuItem(item)) return 1;
+  if (!item->setting) return 0;
   return adjustMenuItem(item, decrementMenuItem);
 }
 
@@ -559,56 +782,54 @@ incrementMenuItem (const MenuItem *item) {
 }
 
 int
-changeMenuItemNext (const MenuItem *item) {
+changeMenuItemNext (MenuItem *item) {
+  if (activateMenuItem(item)) return 1;
+  if (!item->setting) return 0;
   return adjustMenuItem(item, incrementMenuItem);
 }
 
 int
-changeMenuItemScaled (const MenuItem *item, unsigned int index, unsigned int count) {
-  unsigned char oldSetting = *item->setting;
+changeMenuItemScaled (MenuItem *item, unsigned int index, unsigned int count) {
+  if (activateMenuItem(item)) return 1;
 
-  if (item->getValue == getMenuItemValue_numeric) {
-    *item->setting = rescaleInteger(index, count-1, item->maximum-item->minimum) + item->minimum;
-  } else {
-    *item->setting = index % (item->maximum + 1);
+  if (item->setting) {
+    unsigned char oldSetting = *item->setting;
+
+    if (item->methods->getValue == getValue_numeric) {
+      *item->setting = rescaleInteger(index, count-1, item->maximum-item->minimum) + item->minimum;
+    } else {
+      *item->setting = index % (item->maximum + 1);
+    }
+
+    if (!item->changed || item->changed(item, *item->setting)) return 1;
+    *item->setting = oldSetting;
   }
 
-  if (!item->changed || item->changed(item, *item->setting)) return 1;
-  *item->setting = oldSetting;
   return 0;
 }
 
-int
-setMenuPreviousItem (Menu *menu) {
-  do {
-    if (!menu->index) menu->index = menu->count;
-    if (!menu->index) return 0;
-  } while (!testMenuItem(menu, --menu->index));
+MenuItem *
+getCurrentMenuItem (Menu *menu) {
+  MenuItem *newItem = getSelectedMenuItem(menu);
+  MenuItem *oldItem = menu->activeItem;
 
-  return 1;
+  if (newItem != oldItem) {
+    if (oldItem) endMenuItem(oldItem, 0);
+    menu->activeItem = beginMenuItem(newItem)? newItem: NULL;
+  }
+
+  return newItem;
 }
 
-int
-setMenuNextItem (Menu *menu) {
-  if (menu->index >= menu->count) return 0;
+Menu *
+getCurrentSubmenu (Menu *menu) {
+  while (1) {
+    MenuItem *item = getCurrentMenuItem(menu);
 
-  do {
-    if (++menu->index == menu->count) menu->index = 0;
-  } while (!testMenuItem(menu, menu->index));
+    if (item->methods != &menuItemMethods_submenu) break;
+    if (!item->data.submenu->opened) break;
+    menu = item->data.submenu->menu;
+  }
 
-  return 1;
-}
-
-int
-setMenuFirstItem (Menu *menu) {
-  if (!menu->count) return 0;
-  menu->index = 0;
-  return testMenuItem(menu, menu->index) || setMenuNextItem(menu);
-}
-
-int
-setMenuLastItem (Menu *menu) {
-  if (!menu->count) return 0;
-  menu->index = menu->count - 1;
-  return testMenuItem(menu, menu->index) || setMenuPreviousItem(menu);
+  return menu;
 }
