@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2011 by The BRLTTY Developers.
+ * Copyright (C) 1995-2012 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -27,7 +27,7 @@ typedef struct NoteDeviceStruct NoteDevice;
 
 typedef struct {
   NoteDevice * (*construct) (int errorLevel);
-  int (*play) (NoteDevice *device, int note, int duration);
+  int (*play) (NoteDevice *device, unsigned char note, unsigned int duration);
   int (*flush) (NoteDevice *device);
   void (*destruct) (NoteDevice *device);
 } NoteMethods;
@@ -37,8 +37,19 @@ extern const NoteMethods pcmMethods;
 extern const NoteMethods midiMethods;
 extern const NoteMethods fmMethods;
 
-extern const float noteFrequencies[];
-extern const unsigned int noteCount;
+extern int32_t getIntegerNoteFrequency (unsigned char note);
+
+#ifndef NO_FLOAT
+extern float getRealNoteFrequency (unsigned char note);
+#endif /* NO_FLOAT */
+
+#ifdef NO_FLOAT
+#define NOTE_FREQUENCY_TYPE int32_t
+#define GET_NOTE_FREQUENCY getIntegerNoteFrequency
+#else /* NO_FLOAT */
+#define NOTE_FREQUENCY_TYPE float
+#define GET_NOTE_FREQUENCY getRealNoteFrequency
+#endif /* NO_FLOAT */
 
 #ifdef __cplusplus
 }
