@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2011 by The BRLTTY Developers.
+ * Copyright (C) 1995-2012 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -29,9 +29,13 @@
 #include "log.h"
 #include "file.h"
 #include "parse.h"
-#include "misc.h"
 #include "system.h"
 
+#undef ALLOW_DOS_OPTION_SYNTAX
+#if defined(__MINGW32__) || defined(__MSDOS__)
+#define ALLOW_DOS_OPTION_SYNTAX
+#endif /* allow DOS syntax */
+
 #ifdef HAVE_GETOPT_H
 #include <getopt.h>
 #endif /* HAVE_GETOPT_H */
@@ -39,8 +43,12 @@
 typedef struct {
   const OptionEntry *optionTable;
   unsigned int optionCount;
+
   unsigned char ensuredSettings[0X100];
-  int errorCount;
+
+  unsigned exitImmediately:1;
+  unsigned warning:1;
+  unsigned syntaxError:1;
 } OptionProcessingInformation;
 
 static int
@@ -53,25 +61,38 @@ wordMeansFalse (const char *word) {
   return strcasecmp(word, FLAG_FALSE_WORD) == 0;
 }
 
-static void
+static int
 extendSetting (char **setting, const char *value, int prepend) {
   if (value && *value) {
     if (!*setting) {
-      *setting = strdupWrapper(value);
-    } else if (prepend) {
-      char *area = mallocWrapper(strlen(value) + 1 + strlen(*setting) + 1);
-      sprintf(area, "%s,%s", value, *setting);
-      free(*setting);
-      *setting = area;
+      if (!(*setting = strdup(value))) {
+        logMallocError();
+        return 0;
+      }
     } else {
-      size_t length = strlen(*setting);
-      *setting = reallocWrapper(*setting, length+1+strlen(value)+1);
-      sprintf((*setting)+length, ",%s", value);
+      size_t newSize = strlen(*setting) + 1 + strlen(value) + 1;
+      char *newSetting = malloc(newSize);
+
+      if (!newSetting) {
+        logMallocError();
+        return 0;
+      }
+
+      if (prepend) {
+        snprintf(newSetting, newSize, "%s,%s", value, *setting);
+      } else {
+        snprintf(newSetting, newSize, "%s,%s", *setting, value);
+      }
+
+      free(*setting);
+      *setting = newSetting;
     }
   }
+
+  return 1;
 }
 
-static void
+static int
 ensureSetting (
   OptionProcessingInformation *info,
   const OptionEntry *option,
@@ -85,9 +106,12 @@ ensureSetting (
     if (option->argument) {
       if (option->setting.string) {
         if (option->flags & OPT_Extend) {
-          extendSetting(option->setting.string, value, 1);
+          if (!extendSetting(option->setting.string, value, 1)) return 0;
         } else {
-          *option->setting.string = strdupWrapper(value);
+          if (!(*option->setting.string = strdup(value))) {
+            logMallocError();
+            return 0;
+          }
         }
       }
     } else {
@@ -98,19 +122,21 @@ ensureSetting (
           *option->setting.flag = 0;
         } else if (!(option->flags & OPT_Extend)) {
           logMessage(LOG_ERR, "%s: %s", gettext("invalid flag setting"), value);
-          info->errorCount++;
+          info->warning = 1;
         } else {
           int count;
           if (isInteger(&count, value) && (count >= 0)) {
             *option->setting.flag = count;
           } else {
             logMessage(LOG_ERR, "%s: %s", gettext("invalid counter setting"), value);
-            info->errorCount++;
+            info->warning = 1;
           }
         }
       }
     }
   }
+
+  return 1;
 }
 
 static void
@@ -245,8 +271,10 @@ processCommandLine (
   const char *reset = NULL;
   int resetLetter;
 
+#ifdef ALLOW_DOS_OPTION_SYNTAX
   const char dosPrefix = '/';
   int dosSyntax = 0;
+#endif /* ALLOW_DOS_OPTION_SYNTAX */
 
   int optHelp = 0;
   int optHelpAll = 0;
@@ -266,24 +294,32 @@ processCommandLine (
         opt->has_arg = entry->argument? required_argument: no_argument;
         opt->flag = NULL;
         opt->val = entry->letter;
-        ++opt;
+        opt += 1;
 
         if (!entry->argument && entry->setting.flag) {
-          static const char *prefix = "no-";
-          int length = strlen(prefix);
+          static const char *const noPrefix = "no-";
+          size_t noLength = strlen(noPrefix);
+          char *name;
 
-          if (strncasecmp(prefix, entry->word, length) == 0) {
-            opt->name = strdupWrapper(entry->word + length);
+          if (strncasecmp(noPrefix, entry->word, noLength) == 0) {
+            name = strdup(&entry->word[noLength]);
           } else {
-            char *name = mallocWrapper(length + strlen(entry->word) + 1);
-            sprintf(name, "%s%s", prefix, entry->word);
-            opt->name = name;
+            size_t size = noLength + strlen(entry->word) + 1;
+
+            if ((name = malloc(size))) {
+              snprintf(name, size, "%s%s", noPrefix, entry->word);
+            }
           }
 
-          opt->has_arg = no_argument;
-          opt->flag = &resetLetter;
-          opt->val = entry->letter;
-          ++opt;
+          if (name) {
+            opt->name = name;
+            opt->has_arg = no_argument;
+            opt->flag = &resetLetter;
+            opt->val = entry->letter;
+            opt += 1;
+          } else {
+            logMallocError();
+          }
         }
       }
     }
@@ -292,7 +328,7 @@ processCommandLine (
   }
 #endif /* HAVE_GETOPT_LONG */
 
-  for (index=0; index<0X100; ++index) optionEntries[index] = NULL;
+  for (index=0; index<0X100; index+=1) optionEntries[index] = NULL;
 
   {
     char *opt = shortOptions;
@@ -316,8 +352,9 @@ processCommandLine (
   }
 
   if (*argumentCount > 1)
-    if (*(*argumentVector)[1] == dosPrefix)
-      dosSyntax = 1;
+#ifdef ALLOW_DOS_OPTION_SYNTAX
+    if (*(*argumentVector)[1] == dosPrefix) dosSyntax = 1;
+#endif /* ALLOW_DOS_OPTION_SYNTAX */
 
   opterr = 0;
   optind = 1;
@@ -331,6 +368,7 @@ processCommandLine (
     } else {
       char *argument = (*argumentVector)[optind];
 
+#ifdef ALLOW_DOS_OPTION_SYNTAX
       if (dosSyntax) {
         prefix = dosPrefix;
         optind++;
@@ -391,7 +429,10 @@ processCommandLine (
             }
           }
         }
-      } else if (reset) {
+      } else
+#endif /* ALLOW_DOS_OPTION_SYNTAX */
+
+      if (reset) {
         prefix = resetPrefix;
 
         if (!(option = *reset++)) {
@@ -448,7 +489,7 @@ processCommandLine (
         } else {
           if (entry->setting.flag) {
             if (entry->flags & OPT_Extend) {
-              ++*entry->setting.flag;
+              *entry->setting.flag += 1;
             } else {
               *entry->setting.flag = 1;
             }
@@ -468,12 +509,12 @@ processCommandLine (
 
       case '?':
         logMessage(LOG_ERR, "%s: %c%c", gettext("unknown option"), prefix, optopt);
-        info->errorCount++;
+        info->syntaxError = 1;
         break;
 
       case ':': /* An invalid option has been specified. */
         logMessage(LOG_ERR, "%s: %c%c", gettext("missing operand"), prefix, optopt);
-        info->errorCount++;
+        info->syntaxError = 1;
         break;
 
       case 'H':                /* help */
@@ -487,15 +528,16 @@ processCommandLine (
 
   if (optHelp) {
     printHelp(info, stdout, 79, argumentsSummary, optHelpAll);
-    exit(0);
+    info->exitImmediately = 1;
   }
 
 #ifdef HAVE_GETOPT_LONG
   {
     struct option *opt = longOptions;
+
     while (opt->name) {
       if (opt->flag) free((char *)opt->name);
-      ++opt;
+      opt += 1;
     }
   }
 #endif /* HAVE_GETOPT_LONG */
@@ -504,26 +546,23 @@ processCommandLine (
 static void
 processBootParameters (
   OptionProcessingInformation *info,
-  const char *parameterName
+  const char *parameter
 ) {
-  char *parameterString;
-  int allocated = 0;
+  const char *value;
+  char *allocated = NULL;
 
-  if ((parameterString = getBootParameters(parameterName))) {
-    allocated = 1;
-  } else if ((parameterString = getenv(parameterName))) {
-    allocated = 0;
-  } else {
-    return;
-  }
+  if (!(value = allocated = getBootParameters(parameter)))
+    if (!(value = getenv(parameter)))
+      return;
 
   {
     int count = 0;
-    char **parameters = splitString(parameterString, ',', &count);
+    char **parameters = splitString(value, ',', &count);
     int optionIndex;
 
     for (optionIndex=0; optionIndex<info->optionCount; ++optionIndex) {
       const OptionEntry *option = &info->optionTable[optionIndex];
+
       if ((option->bootParameter) && (option->bootParameter <= count)) {
         char *parameter = parameters[option->bootParameter-1];
 
@@ -544,7 +583,7 @@ processBootParameters (
     deallocateStrings(parameters);
   }
 
-  if (allocated) free(parameterString);
+  if (allocated) free(allocated);
 }
 
 static void
@@ -552,28 +591,35 @@ processEnvironmentVariables (
   OptionProcessingInformation *info,
   const char *prefix
 ) {
-  int prefixLength = strlen(prefix);
-  int optionIndex;
-  for (optionIndex=0; optionIndex<info->optionCount; ++optionIndex) {
+  size_t prefixLength = strlen(prefix);
+  unsigned int optionIndex;
+
+  for (optionIndex=0; optionIndex<info->optionCount; optionIndex+=1) {
     const OptionEntry *option = &info->optionTable[optionIndex];
+
     if ((option->flags & OPT_Environ) && option->word) {
-      char name[prefixLength + 1 + strlen(option->word) + 1];
-      sprintf(name, "%s_%s", prefix, option->word);
+      size_t nameSize = prefixLength + 1 + strlen(option->word) + 1;
+      char name[nameSize];
+
+      snprintf(name, nameSize, "%s_%s", prefix, option->word);
 
       {
         char *character = name;
+
         while (*character) {
           if (*character == '-') {
             *character = '_';
 	  } else if (islower(*character)) {
             *character = toupper(*character);
           }
-          ++character;
+
+          character += 1;
         }
       }
 
       {
-        char *setting = getenv(name);
+        const char *setting = getenv(name);
+
         if (setting && *setting) ensureSetting(info, option, setting);
       }
     }
@@ -626,25 +672,29 @@ processConfigurationLine (
 
           if (!operand) {
             logMessage(LOG_ERR, "%s: %s", gettext("operand not supplied for configuration directive"), line);
-            conf->info->errorCount++;
+            conf->info->warning = 1;
           } else if (strtok(NULL, delimiters)) {
             while (strtok(NULL, delimiters));
             logMessage(LOG_ERR, "%s: %s", gettext("too many operands for configuration directive"), line);
-            conf->info->errorCount++;
+            conf->info->warning = 1;
           } else {
             char **setting = &conf->settings[optionIndex];
 
             if (*setting && !(option->argument && (option->flags & OPT_Extend))) {
               logMessage(LOG_ERR, "%s: %s", gettext("configuration directive specified more than once"), line);
-              conf->info->errorCount++;
+              conf->info->warning = 1;
+
               free(*setting);
               *setting = NULL;
             }
 
             if (*setting) {
-              extendSetting(setting, operand, 0);
+              if (!extendSetting(setting, operand, 0)) return 0;
             } else {
-              *setting = strdupWrapper(operand);
+              if (!(*setting = strdup(operand))) {
+                logMallocError();
+                return 0;
+              }
             }
           }
 
@@ -653,58 +703,65 @@ processConfigurationLine (
       }
     }
     logMessage(LOG_ERR, "%s: %s", gettext("unknown configuration directive"), line);
-    conf->info->errorCount++;
+    conf->info->warning = 1;
   }
   return 1;
 }
 
-static int
+static void
 processConfigurationFile (
   OptionProcessingInformation *info,
   const char *path,
   int optional
 ) {
   FILE *file = openDataFile(path, "r", optional);
-  if (file != NULL) { /* The configuration file has been successfully opened. */
-    int processed;
 
-    {
-      ConfigurationFileProcessingData conf;
-      int index;
+  if (file) {
+    ConfigurationFileProcessingData conf;
 
-      conf.info = info;
-      conf.settings = mallocWrapper(info->optionCount * sizeof(*conf.settings));
-      for (index=0; index<info->optionCount; ++index) conf.settings[index] = NULL;
+    conf.info = info;
+      ;
+    if ((conf.settings = malloc(info->optionCount * sizeof(*conf.settings)))) {
+      int processed;
+      unsigned int index;
 
+      for (index=0; index<info->optionCount; index+=1) conf.settings[index] = NULL;
       processed = processLines(file, processConfigurationLine, &conf);
 
-      for (index=0; index<info->optionCount; ++index) {
+      for (index=0; index<info->optionCount; index+=1) {
         char *setting = conf.settings[index];
+
         if (setting) {
           ensureSetting(info, &info->optionTable[index], setting);
           free(setting);
         }
       }
+
+      if (!processed) {
+        logMessage(LOG_ERR, gettext("file '%s' processing error."), path);
+        info->warning = 1;
+      }
+
       free(conf.settings);
+    } else {
+      logMallocError();
     }
 
     fclose(file);
-    if (processed) return 1;
-    logMessage(LOG_ERR, gettext("file '%s' processing error."), path);
-    info->errorCount++;
-  } else {
-    if (optional && (errno == ENOENT)) return 1;
-    info->errorCount++;
+  } else if (!optional || (errno != ENOENT)) {
+    info->warning = 1;
   }
-  return 0;
 }
 
-int
+ProgramExitStatus
 processOptions (const OptionsDescriptor *descriptor, int *argumentCount, char ***argumentVector) {
   OptionProcessingInformation info = {
     .optionTable = descriptor->optionTable,
     .optionCount = descriptor->optionCount,
-    .errorCount = 0
+
+    .exitImmediately = 0,
+    .warning = 0,
+    .syntaxError = 0
   };
 
   {
@@ -712,7 +769,7 @@ processOptions (const OptionsDescriptor *descriptor, int *argumentCount, char **
     for (index=0; index<0X100; ++index) info.ensuredSettings[index] = 0;
   }
 
-  prepareProgram(*argumentCount, *argumentVector);
+  beginProgram(*argumentCount, *argumentVector);
   processCommandLine(&info, argumentCount, argumentVector, descriptor->argumentsSummary);
 
   {
@@ -734,5 +791,7 @@ processOptions (const OptionsDescriptor *descriptor, int *argumentCount, char **
     setDefaultOptions(&info, 1);
   }
 
-  return info.errorCount;
+  if (info.exitImmediately) return PROG_EXIT_FORCE;
+  if (info.syntaxError) return PROG_EXIT_SYNTAX;
+  return PROG_EXIT_SUCCESS;
 }
