@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2011 by The BRLTTY Developers.
+ * Copyright (C) 1995-2012 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -89,7 +89,7 @@ sayLine (char *line, void *data) {
 
 int
 main (int argc, char *argv[]) {
-  int status;
+  ProgramExitStatus exitStatus;
   const char *driver = NULL;
   void *object;
   float speechRate;
@@ -101,7 +101,7 @@ main (int argc, char *argv[]) {
       .applicationName = "spktest",
       .argumentsSummary = "[driver [parameter=value ...]]"
     };
-    processOptions(&descriptor, &argc, &argv);
+    PROCESS_OPTIONS(descriptor, argc, argv);
   }
 
   {
@@ -119,7 +119,7 @@ main (int argc, char *argv[]) {
     static const float maximum = 10.0;
     if (!validateFloat(&speechRate, opt_speechRate, &minimum, &maximum)) {
       logMessage(LOG_ERR, "%s: %s", "invalid rate multiplier", opt_speechRate);
-      exit(2);
+      return PROG_EXIT_SYNTAX;
     }
   }
 
@@ -129,7 +129,7 @@ main (int argc, char *argv[]) {
     static const float maximum = 2.0;
     if (!validateFloat(&speechVolume, opt_speechVolume, &minimum, &maximum)) {
       logMessage(LOG_ERR, "%s: %s", "invalid volume multiplier", opt_speechVolume);
-      exit(2);
+      return PROG_EXIT_SYNTAX;
     }
   }
 
@@ -152,8 +152,8 @@ main (int argc, char *argv[]) {
       while (*name) ++name;
       count = name - parameterNames;
       if (!(parameterSettings = malloc((count + 1) * sizeof(*parameterSettings)))) {
-        logMessage(LOG_ERR, "insufficient memory.");
-        exit(9);
+        logMallocError();
+        return PROG_EXIT_FATAL;
       }
       setting = parameterSettings;
       while (count--) *setting++ = "";
@@ -180,15 +180,15 @@ main (int argc, char *argv[]) {
         }
         if (!ok) logMessage(LOG_ERR, "invalid speech driver parameter: %s", assignment);
       }
-      if (!ok) exit(2);
+      if (!ok) return PROG_EXIT_SYNTAX;
       --argc;
     }
 
     initializeSpeechSynthesizer(&spk);
     identifySpeechDriver(speech, 0);		/* start-up messages */
     if (speech->construct(&spk, parameterSettings)) {
-      if (speech->rate) speech->rate(&spk, speechRate);
-      if (speech->volume) speech->volume(&spk, speechVolume);
+      if (speech->setVolume) speech->setVolume(&spk, speechVolume);
+      if (speech->setRate) speech->setRate(&spk, speechRate);
 
       if (opt_textString && *opt_textString) {
         sayString(&spk, opt_textString, 0);
@@ -196,14 +196,14 @@ main (int argc, char *argv[]) {
         processLines(stdin, sayLine, NULL);
       }
       speech->destruct(&spk);		/* finish with the display */
-      status = 0;
+      exitStatus = PROG_EXIT_SUCCESS;
     } else {
       logMessage(LOG_ERR, "can't initialize speech driver.");
-      status = 5;
+      exitStatus = PROG_EXIT_FATAL;
     }
   } else {
     logMessage(LOG_ERR, "can't load speech driver.");
-    status = 3;
+    exitStatus = PROG_EXIT_FATAL;
   }
-  return status;
+  return exitStatus;
 }
