@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2011 by The BRLTTY Developers.
+ * Copyright (C) 1995-2012 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -41,7 +41,6 @@
 #include "file.h"
 #include "parse.h"
 #include "timing.h"
-#include "misc.h"
 #include "mount.h"
 #include "io_usb.h"
 #include "usb_internal.h"
@@ -154,6 +153,9 @@ usbGetDriver (UsbDevice *device, unsigned char interface) {
     if (ioctl(devx->usbfsFile, USBDEVFS_GETDRIVER, &arg) != -1) {
       char *name = strdup(arg.driver);
       if (name) return name;
+      logMallocError();
+    } else {
+      logSystemError("USB get driver name");
     }
   }
 
@@ -189,8 +191,10 @@ usbDisconnectDriver (UsbDevice *device, unsigned char interface) {
 #ifdef USBDEVFS_DISCONNECT
   if (usbControlDriver(device, interface, USBDEVFS_DISCONNECT, NULL)) return 1;
 #else /* USBDEVFS_DISCONNECT */
-  logMessage(LOG_WARNING, "USB driver disconnection not available.");
+  errno = ENOSYS;
 #endif /* USBDEVFS_DISCONNECT */
+
+  logSystemError("USAB driver disconnect");
   return 0;
 }
 
@@ -199,10 +203,16 @@ usbDisconnectInterface (UsbDevice *device, unsigned char interface) {
   char *driver = usbGetDriver(device, interface);
 
   if (driver) {
+    int isUsbfs = strcmp(driver, "usbfs") == 0;
+
     logMessage(LOG_WARNING, "USB interface in use: %u (%s)", interface, driver);
     free(driver);
 
-    if (usbDisconnectDriver(device, interface)) return 1;
+    if (isUsbfs) {
+      errno = EBUSY;
+    } else if (usbDisconnectDriver(device, interface)) {
+      return 1;
+    }
   }
 
   return 0;
@@ -335,9 +345,9 @@ usbControlTransfer (
     memset(&arg, 0, sizeof(arg));
     arg.setup.bRequestType = direction | recipient | type;
     arg.setup.bRequest = request;
-    putLittleEndian(&arg.setup.wValue, value);
-    putLittleEndian(&arg.setup.wIndex, index);
-    putLittleEndian(&arg.setup.wLength, length);
+    putLittleEndian16(&arg.setup.wValue, value);
+    putLittleEndian16(&arg.setup.wIndex, index);
+    putLittleEndian16(&arg.setup.wLength, length);
     arg.transfer.data = buffer;
     arg.transfer.timeout = timeout;
 
@@ -687,7 +697,7 @@ usbWriteEndpoint (
         struct usbdevfs_urb *urb = usbInterruptTransfer(endpoint, (void *)buffer, length, timeout);
 
         if (urb) {
-          int count = urb->actual_length;
+          ssize_t count = urb->actual_length;
           free(urb);
           return count;
         }
@@ -866,11 +876,11 @@ usbReadHostDeviceDescriptor (UsbHostDevice *host) {
     } else {
       ok = 1;
 
-      if (sysfs) {
-        host->usbDescriptor.bcdUSB = getLittleEndian(host->usbDescriptor.bcdUSB);
-        host->usbDescriptor.idVendor = getLittleEndian(host->usbDescriptor.idVendor);
-        host->usbDescriptor.idProduct = getLittleEndian(host->usbDescriptor.idProduct);
-        host->usbDescriptor.bcdDevice = getLittleEndian(host->usbDescriptor.bcdDevice);
+      if (!sysfs) {
+        host->usbDescriptor.bcdUSB = getLittleEndian16(host->usbDescriptor.bcdUSB);
+        host->usbDescriptor.idVendor = getLittleEndian16(host->usbDescriptor.idVendor);
+        host->usbDescriptor.idProduct = getLittleEndian16(host->usbDescriptor.idProduct);
+        host->usbDescriptor.bcdDevice = getLittleEndian16(host->usbDescriptor.bcdDevice);
       }
     }
 
@@ -966,7 +976,13 @@ usbGetFileSystem (const char *type, const FileSystemCandidate *candidates, Mount
 
     while (candidate->path) {
       logMessage(LOG_DEBUG, "verifying file system path: %s: %s", type, candidate->path);
-      if (candidate->verify(candidate->path)) return strdupWrapper(candidate->path);
+
+      if (candidate->verify(candidate->path)) {
+        char *path = strdup(candidate->path);
+        if (path) return path;
+        logMallocError();
+      }
+
       candidate += 1;
     }
   }
