@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2011 by The BRLTTY Developers.
+ * Copyright (C) 1995-2012 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -23,7 +23,7 @@
 extern "C" {
 #endif /* __cplusplus */
 
-#define PACKAGE_COPYRIGHT "Copyright (C) 1995-2011 by The BRLTTY Developers."
+#define PACKAGE_COPYRIGHT "Copyright (C) 1995-2012 by The BRLTTY Developers."
 #define PACKAGE_URL "http://mielke.cc/brltty/"
 
 #define _CONCATENATE(a,b) a##b
@@ -48,8 +48,11 @@ extern "C" {
 #define STR_LEFT (strEnd - strNext)
 #define STR_ADJUST(length) if ((strNext += (length)) > strEnd) strNext = strEnd
 #define STR_PRINTF(format, ...) { \
-  int strLength; \
-  snprintf(STR_NEXT, STR_LEFT, format "%n", ## __VA_ARGS__, &strLength); \
+  size_t strLength = snprintf(STR_NEXT, STR_LEFT, format, ## __VA_ARGS__); \
+  STR_ADJUST(strLength); \
+}
+#define STR_VPRINTF(format, arguments) { \
+  size_t strLength = vsnprintf(STR_NEXT, STR_LEFT, format, arguments); \
   STR_ADJUST(strLength); \
 }
 
@@ -95,6 +98,26 @@ extern void usleep (int usec);
 #endif /* usleep */
 #endif /* __MINGW32__ */
 
+#ifdef GRUB_RUNTIME
+#undef NESTED_FUNC_ATTR
+#define NESTED_FUNC_ATTR __attribute__((__regparm__(1)))
+
+/* missing needed standard integer definitions */
+#define INT16_MAX 0X7FFF
+#define INT32_MAX 0X7FFFFFFF
+#define UINT32_C(i) (i)
+#define PRIuGRUB_UINT16_T "u"
+#define PRIuGRUB_UINT8_T "u"
+
+/* to get gettext() declared */
+#define GRUB_POSIX_GETTEXT_DOMAIN "brltty"
+
+/* disable the use of floating-point operations */
+#define NO_FLOAT
+#define float NO_FLOAT
+#define double NO_DOUBLE
+#endif /* GRUB_RUNHTIME */
+
 #ifdef __MSDOS__
 #include <stdarg.h>
 
@@ -238,7 +261,11 @@ WIN_ERRNO_STORAGE_CLASS int win_toErrno (DWORD error);
 #define setSocketErrno() setErrno(getSocketError())
 
 #ifdef HAVE_CONFIG_H
+#ifdef FOR_BUILD
+#include "forbuild.h"
+#else /* FOR_BUILD */
 #include "config.h"
+#endif /* FOR_BUILD */
 #endif /* HAVE_CONFIG_H */
 
 #ifdef HAVE_WCHAR_H 
@@ -329,6 +356,28 @@ convertTextToWchars (wchar_t *characters, const char *text, size_t size) {
   return length;
 }
 
+typedef unsigned char mbstate_t;
+
+static inline size_t
+mbrtowc (wchar_t *pwc, const char *s, size_t n, mbstate_t *ps) {
+  if (!s) return 0;
+  if (!n) return 0;
+  if (pwc) *pwc = *s & 0XFF;
+  if (!*s) return 0;
+  return 1;
+}
+
+static inline size_t
+wcrtomb (char *s, wchar_t wc, mbstate_t *ps) {
+  if (s) *s = wc;
+  return 1;
+}
+
+static inline int
+mbsinit (const mbstate_t *ps) {
+  return 1;
+}
+
 #define WC_C(wc) (wchar_t)wc
 #define WS_C(ws) (const wchar_t *)ws
 #define PRIwc "c"
@@ -348,6 +397,22 @@ convertTextToWchars (wchar_t *characters, const char *text, size_t size) {
 #define WRITABLE_DIRECTORY ""
 #endif /* WRITABLE_DIRECTORY */
 
+#ifndef PRINTF
+#ifdef HAVE_ATTRIBUTE_FORMAT_PRINTF
+#define PRINTF(fmt,var) __attribute__((format(__printf__, fmt, var)))
+#else /* HAVE_ATTRIBUTE_FORMAT_PRINTF */
+#define PRINTF(fmt,var)
+#endif /* HAVE_ATTRIBUTE_FORMAT_PRINTF */
+#endif /* PRINTF */
+
+#ifndef NORETURN
+#ifdef HAVE_ATTRIBUTE_NORETURN
+#define NORETURN __attribute__((noreturn))
+#else /* HAVE_ATTRIBUTE_NORETURN */
+#define NORETURN
+#endif /* HAVE_ATTRIBUTE_NORETURN */
+#endif /* NORETURN */
+
 #ifndef PACKED
 #ifdef HAVE_ATTRIBUTE_PACKED
 #define PACKED __attribute__((packed))
@@ -356,17 +421,13 @@ convertTextToWchars (wchar_t *characters, const char *text, size_t size) {
 #endif /* HAVE_ATTRIBUTE_PACKED */
 #endif /* PACKED */
 
-#ifdef HAVE_ATTRIBUTE_FORMAT_PRINTF
-#define PRINTF(fmt,var) __attribute__((format(__printf__, fmt, var)))
-#else /* HAVE_ATTRIBUTE_FORMAT_PRINTF */
-#define PRINTF(fmt,var)
-#endif /* HAVE_ATTRIBUTE_FORMAT_PRINTF */
-
+#ifndef UNUSED
 #ifdef HAVE_ATTRIBUTE_UNUSED
 #define UNUSED __attribute__((unused))
 #else /* HAVE_ATTRIBUTE_UNUSED */
 #define UNUSED
 #endif /* HAVE_ATTRIBUTE_UNUSED */
+#endif /* UNUSED */
 
 #ifdef ENABLE_I18N_SUPPORT
 #include <libintl.h>
@@ -381,11 +442,24 @@ convertTextToWchars (wchar_t *characters, const char *text, size_t size) {
 #define PRIX_KEY_T PRIX32
 #elif SIZEOF_KEY_T == 8
 #define PRIX_KEY_T PRIX64
-#else /* SIZEOF_KEY_T */
-#error unsupported size for type key_t
 #endif /* SIZEOF_KEY_T */
 #endif /* HAVE_SHMGET */
 
+/* configure is still making a few mistakes with respect to the grub environment */
+#ifdef GRUB_RUNTIME
+
+/* some headers exist but probably shouldn't */
+#undef HAVE_SIGNAL_H
+
+/* including <time.h> on its own yields compile errors */
+#undef HAVE_DECL_LOCALTIME_R
+#define HAVE_DECL_LOCALTIME_R 1
+
+/* AC_CHECK_FUNC() is checking local libraries - these are the errors that matter */
+#undef HAVE_FCHDIR
+#undef HAVE_SELECT
+#endif /* GRUB_RUNTIME */
+
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
